@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import warnings
 from typing import Any
 
 from strawberry.test.client import BaseGraphQLTestClient, Response
@@ -12,7 +11,6 @@ class GraphQLTestClient(BaseGraphQLTestClient):
         query: str,
         variables: dict[str, Any] | None = None,
         headers: dict[str, object] | None = None,
-        asserts_errors: bool | None = None,
         files: dict[str, object] | None = None,
         assert_no_errors: bool | None = True,
     ) -> Response:
@@ -27,17 +25,6 @@ class GraphQLTestClient(BaseGraphQLTestClient):
             extensions=data.get("extensions"),
         )
 
-        if asserts_errors is not None:
-            warnings.warn(
-                "The `asserts_errors` argument has been renamed to `assert_no_errors`",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
-        assert_no_errors = (
-            assert_no_errors if asserts_errors is None else asserts_errors
-        )
-
         if assert_no_errors:
             assert resp.status == 200
             assert response.errors is None
